'use strict';

const { TemplateHelper: th } = require('@squeep/html-template-helper');
const { sessionNavLinks } = require('./helpers');

/**
 *
 * @returns {String}
 */
function mainContent() {
  return [
    `<section>
\t<a href="./login">Try Again?</a>
</section>`,
  ];
}

/**
 * Render any errors from attempting IndieAuth.
 * @param {Object} ctx
 * @param {String[]} ctx.errors
 * @param {Object} options
 * @param {Object} options.manager
 * @param {String} options.manager.pageTitle
 * @param {Object} options.dingus
 * @param {String} options.dingus.selfBaseUrl
 * @param {(pagePathLevel, ctx, htmlOptions) => {void}} appCb
 * @returns {String}
 */
module.exports = (ctx, options, appCb = () => {}) => {
  const pagePathLevel = 1;
  const htmlOptions = {
    pageIdentifier: 'indieAuthError',
    pageTitle: options.manager.pageTitle,
    logoUrl: options.manager.logoUrl,
    footerEntries: options.manager.footerEntries,
    errorContent: [
      '<p>Problems were encountered while trying to authenticate your profile URL.</p>',
    ],
  };
  appCb(pagePathLevel, ctx, htmlOptions);
  sessionNavLinks(pagePathLevel, ctx, htmlOptions);

  // Ensure there is always an error to report, even if we do not have one, as we ended up here somehow.
  if (!ctx?.errors?.length) {
    ctx.errors = [
      'Unknown Error &mdash; we are not sure what just happened',
    ];
  }
  return th.htmlPage(pagePathLevel, ctx, htmlOptions, mainContent());
};