/* eslint-env mocha */
'use strict';

const assert = require('assert');
const { LoginHTML } = require('../../../lib/template');
const lintHtml = require('../../lint-html');

describe('Template LoginHTML', function () {
  let ctx, options;
  beforeEach(function () {
    ctx = {
      clientProtocol: 'https',
    };
    options = {
      authenticator: {
        authnEnabled: ['indieAuth'],
        secureAuthOnly: true,
      },
      manager: {
        pageTitle: 'page',
      },
      dingus: {
        selfBaseUrl: 'https://example.com/',
      },
    };
  });

  it('covers', async function () {
    const result = LoginHTML(ctx, options);
    await lintHtml(result);
    assert(result);
  });

  it('covers local user', async function () {
    options.authenticator.authnEnabled = ['argon2'];
    const result = LoginHTML(ctx, options);
    await lintHtml(result);
    assert(result);
  });

  it('renders errors and additional content', async function () {
    ctx.errors = ['an error', 'another error'];
    options.manager.logoUrl = 'https://example.com/logo.png';
    options.authenticator.loginBlurb = ['<p>This is a login page.</p>'];
    options.authenticator.indieAuthBlurb = ['<p>Describe what IndieAuth allows one to do.</p>'];
    options.authenticator.userBlurb = ['<p>Describe user login.</p>'];
    const result = LoginHTML(ctx, options);
    await lintHtml(result);
    assert(result);
  });

  it('covers no indieAuth', async function () {
    options.authenticator.authnEnabled = [];
    const result = LoginHTML(ctx, options);
    await lintHtml(result);
    assert(result);
  });

  it('covers insecure not allowed', async function () {
    ctx.clientProtocol = undefined;
    const result = LoginHTML(ctx, options);
    await lintHtml(result);
    assert(result);
  });

  it('covers insecure allowed', async function () {
    ctx.clientProtocol = 'http';
    options.authenticator.secureAuthOnly = false;
    const result = LoginHTML(ctx, options);
    await lintHtml(result);
    assert(result);
  });

});